==> phosphorus-0.8.3.tar.gz: phosphorus-0.8.3/docs/README.md <==
# phosphorus: A dependency management and packaging tool

[![build][build_badge]][build_url]
[![lint][lint_badge]][lint_url]
[![tests][test_badge]][test_url]
[![license][licence_badge]][licence_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`phosphorus` is a dependency management and packaging tool replacement tool that's
been heavily influenced by [poetry][poetry]. The main goal of phosphorus is to have minimal
external dependencies, although some common packaging tools are required.

## Links

-   [Documentation]
-   [Changelog]

[build_badge]: https://github.com/spapanik/phosphorus/actions/workflows/build.yml/badge.svg
[build_url]: https://github.com/spapanik/phosphorus/actions/workflows/build.yml
[lint_badge]: https://github.com/spapanik/phosphorus/actions/workflows/lint.yml/badge.svg
[lint_url]: https://github.com/spapanik/phosphorus/actions/workflows/lint.yml
[test_badge]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml/badge.svg
[test_url]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/pypi/l/phosphorus
[licence_url]: https://phosphorus.readthedocs.io/en/stable/LICENSE/
[pypi_badge]: https://img.shields.io/pypi/v/phosphorus
[pypi_url]: https://pypi.org/project/phosphorus
[pepy_badge]: https://pepy.tech/badge/phosphorus
[pepy_url]: https://pepy.tech/project/phosphorus
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://phosphorus.readthedocs.io/en/stable/
[Changelog]: https://phosphorus.readthedocs.io/en/stable/CHANGELOG/
[poetry]: https://python-poetry.org/

==> phosphorus-0.9.0.tar.gz: phosphorus-0.9.0/docs/README.md <==
# phosphorus: A dependency management and packaging tool

[![build][build_badge]][build_url]
[![lint][lint_badge]][lint_url]
[![tests][tests_badge]][tests_url]
[![license][licence_badge]][licence_url]
[![codecov][codecov_badge]][codecov_url]
[![readthedocs][readthedocs_badge]][readthedocs_url]
[![pypi][pypi_badge]][pypi_url]
[![downloads][pepy_badge]][pepy_url]
[![code style: black][black_badge]][black_url]
[![build automation: yam][yam_badge]][yam_url]
[![Lint: ruff][ruff_badge]][ruff_url]

`phosphorus` is a dependency management and packaging tool replacement tool that's
been heavily influenced by [poetry][poetry]. The main goal of phosphorus is to have minimal
external dependencies, although some common packaging tools are required.

## Links

-   [Documentation]
-   [Changelog]

[build_badge]: https://github.com/spapanik/phosphorus/actions/workflows/build.yml/badge.svg
[build_url]: https://github.com/spapanik/phosphorus/actions/workflows/build.yml
[lint_badge]: https://github.com/spapanik/phosphorus/actions/workflows/lint.yml/badge.svg
[lint_url]: https://github.com/spapanik/phosphorus/actions/workflows/lint.yml
[tests_badge]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml/badge.svg
[tests_url]: https://github.com/spapanik/phosphorus/actions/workflows/tests.yml
[licence_badge]: https://img.shields.io/pypi/l/phosphorus
[licence_url]: https://phosphorus.readthedocs.io/en/stable/LICENSE/
[codecov_badge]: https://codecov.io/github/spapanik/phosphorus/graph/badge.svg?token=Q20F84BW72
[codecov_url]: https://codecov.io/github/spapanik/phosphorus
[readthedocs_badge]: https://readthedocs.org/projects/phosphorus/badge/?version=latest
[readthedocs_url]: https://phosphorus.readthedocs.io/en/latest/
[pypi_badge]: https://img.shields.io/pypi/v/phosphorus
[pypi_url]: https://pypi.org/project/phosphorus
[pepy_badge]: https://pepy.tech/badge/phosphorus
[pepy_url]: https://pepy.tech/project/phosphorus
[black_badge]: https://img.shields.io/badge/code%20style-black-000000.svg
[black_url]: https://github.com/psf/black
[yam_badge]: https://img.shields.io/badge/build%20automation-yamk-success
[yam_url]: https://github.com/spapanik/yamk
[ruff_badge]: https://img.shields.io/endpoint?url=https://raw.githubusercontent.com/charliermarsh/ruff/main/assets/badge/v1.json
[ruff_url]: https://github.com/charliermarsh/ruff
[Documentation]: https://phosphorus.readthedocs.io/en/stable/
[Changelog]: https://phosphorus.readthedocs.io/en/stable/CHANGELOG/
[poetry]: https://python-poetry.org/
